@@ -152,7 +152,7 @@ stats.norm.ppf(.75)
 print(x)
 
 
-sm.robust.scale.stand_mad(x)
+sm.robust.scale.mad(x)
 
 
 np.array([1,2,3,4,5.]).std()
@@ -186,10 +186,10 @@ loc, scale = huber(fat_tails)
 print(loc, scale)
 
 
-sm.robust.stand_mad(fat_tails)
+sm.robust.mad(fat_tails)
 
 
-sm.robust.stand_mad(fat_tails, c=stats.t(6).ppf(.75))
+sm.robust.mad(fat_tails, c=stats.t(6).ppf(.75))
 
 
 sm.robust.scale.mad(fat_tails)
@@ -210,7 +210,7 @@ print(prestige.head(10))
 fig = plt.figure(figsize=(12,12))
 ax1 = fig.add_subplot(211, xlabel='Income', ylabel='Prestige')
 ax1.scatter(prestige.income, prestige.prestige)
-xy_outlier = prestige.ix['minister'][['income','prestige']]
+xy_outlier = prestige.loc['minister'][['income','prestige']]
 ax1.annotate('Minister', xy_outlier, xy_outlier+1, fontsize=16)
 ax2 = fig.add_subplot(212, xlabel='Education',
                            ylabel='Prestige')
@@ -226,10 +226,10 @@ student = infl.summary_frame()['student_resid']
 print(student)
 
 
-print(student.ix[np.abs(student) > 2])
+print(student.loc[np.abs(student) > 2])
 
 
-print(infl.summary_frame().ix['minister'])
+print(infl.summary_frame().loc['minister'])
 
 
 sidak = ols_model.outlier_test('sidak')
@@ -270,7 +270,7 @@ ax.annotate('Red giants', xy=(3.6, 6), xytext=(3.8, 6),
             fontsize=16,
      )
 # annotate these with their index
-for i,row in dta.ix[dta['log.Te'] < 3.8].iterrows():
+for i,row in dta.loc[dta['log.Te'] < 3.8].iterrows():
     ax.annotate(i, row, row + .01, fontsize=14)
 xlim, ylim = ax.get_xlim(), ax.get_ylim()
 
@@ -296,7 +296,7 @@ infl = ols_model.get_influence()
 
 h_bar = 2*(ols_model.df_model + 1 )/ols_model.nobs
 hat_diag = infl.summary_frame()['hat_diag']
-hat_diag.ix[hat_diag > h_bar]
+hat_diag.loc[hat_diag > h_bar]
 
 
 sidak2 = ols_model.outlier_test('sidak')
